summaryrefslogtreecommitdiff
path: root/chromium/content/utility/utility_thread_impl.h
diff options
context:
space:
mode:
authorAllan Sandfeld Jensen <allan.jensen@qt.io>2017-03-08 10:28:10 +0100
committerAllan Sandfeld Jensen <allan.jensen@qt.io>2017-03-20 13:40:30 +0000
commite733310db58160074f574c429d48f8308c0afe17 (patch)
treef8aef4b7e62a69928dbcf880620eece20f98c6df /chromium/content/utility/utility_thread_impl.h
parent2f583e4aec1ae3a86fa047829c96b310dc12ecdf (diff)
downloadqtwebengine-chromium-e733310db58160074f574c429d48f8308c0afe17.tar.gz
BASELINE: Update Chromium to 56.0.2924.122
Change-Id: I4e04de8f47e47e501c46ed934c76a431c6337ced Reviewed-by: Michael BrĂ¼ning <michael.bruning@qt.io>
Diffstat (limited to 'chromium/content/utility/utility_thread_impl.h')
-rw-r--r--chromium/content/utility/utility_thread_impl.h17
1 files changed, 8 insertions, 9 deletions
diff --git a/chromium/content/utility/utility_thread_impl.h b/chromium/content/utility/utility_thread_impl.h
index c7e88381385..cd53c948149 100644
--- a/chromium/content/utility/utility_thread_impl.h
+++ b/chromium/content/utility/utility_thread_impl.h
@@ -16,11 +16,7 @@
#include "content/common/content_export.h"
#include "content/public/utility/utility_thread.h"
#include "mojo/public/cpp/bindings/binding_set.h"
-#include "services/shell/public/interfaces/service_factory.mojom.h"
-
-namespace base {
-class FilePath;
-}
+#include "services/service_manager/public/interfaces/service_factory.mojom.h"
namespace content {
class BlinkPlatformImpl;
@@ -56,18 +52,21 @@ class UtilityThreadImpl : public UtilityThread,
void OnBatchModeStarted();
void OnBatchModeFinished();
- void BindServiceFactoryRequest(shell::mojom::ServiceFactoryRequest request);
+ void BindServiceFactoryRequest(
+ service_manager::mojom::ServiceFactoryRequest request);
// True when we're running in batch mode.
bool batch_mode_;
std::unique_ptr<UtilityBlinkPlatformImpl> blink_platform_impl_;
- // shell::mojom::ServiceFactory for shell::Service hosting.
+ // service_manager::mojom::ServiceFactory for service_manager::Service
+ // hosting.
std::unique_ptr<UtilityServiceFactory> service_factory_;
- // Bindings to the shell::mojom::ServiceFactory impl.
- mojo::BindingSet<shell::mojom::ServiceFactory> service_factory_bindings_;
+ // Bindings to the service_manager::mojom::ServiceFactory impl.
+ mojo::BindingSet<service_manager::mojom::ServiceFactory>
+ service_factory_bindings_;
DISALLOW_COPY_AND_ASSIGN(UtilityThreadImpl);
};